==> freedom-maker_0.26+10.0trisquel1.tar.gz: freedom-maker-0.26+10.0trisquel1/README.md <==
# Freedom-Maker: The FreedomBox image builder

These scripts build FreedomBox-images for various supported hardware
that can then be copied to SD card, USB stick or Hard Disk drive to
boot into FreedomBox.

These scripts are meant for developers of FreedomBox to build images
during releases and for advanced users who intend to build their own
images. Regular users who wish to turn their devices into
FreedomBoxes should instead download the pre-built images.

Get a pre-built image via https://cdimage.trisquel.info/trisquel-images/. There
are images available for all supported target devices.  You also find
the setup instructions on the [Wiki](https://trisquel.info/en/wiki/FreedomBox/).

If you wish to create your own FreedomBox image, perhaps with some
tweaks, see the *Build Images* section below.

# Create Images

## Supported Targets

Trisquel Freedom-maker supports building for the following targets:

| target                | description |
|-----------------------|-------------|
| *a20-olinuxino-lime*  | A20 OLinuXino Lime's SD card |
| *a20-olinuxino-lime2* | A20 OLinuXino Lime2's SD card |
| *a20-olinuxino-micro* | A20 OLinuXino MICRO's SD card |
| *amd64*               | Disk image for any machine with amd64 architecture |
| *banana-pro*          | Banana Pro's SD card |
| *beaglebone*          | BeagleBone Black's SD card |
| *cubieboard2*         | Cubieboard2's SD card |
| *cubietruck*          | Cubietruck's SD card |
| *i386*                | Disk image for any machine with i386 architecture |
| *lamobo-r1*           | Lamobo R1 aka BananaPi Router SD card |
| *pcduino3*            | pcDuino3's SD card |
| *pine64-lts*          | Pine64 LTS board's SD card |
| *pine64-plus*         | Pine64+ board's SD card |
| *qemu-amd64*          | 64-bit image for the Qemu virtualization tool |
| *qemu-i386*           | 32-bit image for the Qemu virtualization tool |

## Running Build

1. Fetch the 'freedom-maker' source code:
    ```
    $ apt source freedom-maker
    ```

2. Install the required dependencies:
    ```shell
    $ sudo apt install btrfs-progs debootstrap kpartx parted qemu-user-static sshpass
    $ sudo apt build-dep freedom-maker
    ```

3. Build images:

    This command has to be started with root (sudo) permission because it needs
    to run "parted".

    ```
    $ cd $(find -type d -name 'freedom-maker-*')
    $ sudo python3 -m freedommaker <TARGET>
    ```
    where: &lt;TARGET&gt; is one of the 'Supported Targets' above.

    Take a break from your computer - this takes some time. :)

    To see the full list of options read the help-page:
    ```
    $ python3 -m freedommaker --help
    ```

The image will show up in *build/*. Copy the image to the
target disk following the instructions in the *Use Images* section.

# Use Images

You'll need to copy the image to a memory card or USB stick. If you don't
use GNU/Linux or prefer a GUI we recommend [etcher](https://etcher.io/)
for this task. Otherwise follow the steps:

1. Figure out which device your card actually is.

    A. Unplug your card.

    B. Run `lsblk -p` to show which storage devices are connected to your system.
    For example, if your computer has one internal SATA storage device
    (the most common configuration), it will be identified as */dev/sda*;
    and the result may look similar to this:

        $ lsblk -p
        NAME        MAJ:MIN RM   SIZE RO TYPE MOUNTPOINTS
        /dev/sda      8:0    0 119.2G  0 disk
        ├─/dev/sda1   8:1    0     2G  0 part /boot
        ├─/dev/sda2   8:2    0  22.5G  0 part /
        └─/dev/sda3   8:3    0  94.8G  0 part /home

    C. Plug in your SDcard and run `lsblk -p` again. Find the new device and note
    the name. For example, if the SDcard is unformatted (empty), the result may
    look similar to this:

        $ lsblk -p
        NAME        MAJ:MIN RM   SIZE RO TYPE MOUNTPOINTS
        /dev/sda      8:0    0 119.2G  0 disk
        ├─/dev/sda1   8:1    0     2G  0 part /boot
        ├─/dev/sda2   8:2    0  22.5G  0 part /
        └─/dev/sda3   8:3    0  94.8G  0 part /home
        /dev/sdb      8:32   1  29.7G  0 disk

    Or, if the SDcard is already formatted, it may look more like this:

        $ lsblk -p
        NAME        MAJ:MIN RM   SIZE RO TYPE MOUNTPOINTS
        /dev/sda      8:0    0 119.2G  0 disk
        ├─/dev/sda1   8:1    0     2G  0 part /boot
        ├─/dev/sda2   8:2    0  22.5G  0 part /
        └─/dev/sda3   8:3    0  94.8G  0 part /home
        /dev/sdb      8:32   1  29.7G  0 disk
        ├─/dev/sdb1   8:33   1   100M  0 part
        └─/dev/sdb2   8:36   1  29.6G  0 part

    D. In the above cases, the newly inserted SDcard is identified
       as */dev/sdb*. To be more certain, you can compare the reported sizes
       (approximately - the SDcard is 30 GB in this example - reported 29.7G).
       Most importantly, */dev/sda*. is usually not the SDcard.
       Carefully note this identifier and use it in the copying step below.

2. Copy the image to your card.  Double check and make sure you don't
   write to your computer's main storage (such as /dev/sda).  Also
   make sure that you don't run this step as root (sudo) to avoid potentially
   overriding data on your hard drive due to a mistake. USB disks and SD
   cards inserted into the system should typically be write accessible
   to normal users. If you don't have permission to write to your SD
   card as a user, you may need to run this command as root. In this
   case triple check everything before you run the command. Another
   safety precaution is to unplug all external disks except the SD
   card before running the command.

   For example, if your SD card is /dev/sdg use the following command:
    ```
    $ xzcat build/freedombox-unstable_2018-08-06_beaglebone-armhf.img.xz | dd bs=4M of=/dev/sdg conv=fsync status=progress
    ```

   The above command is an example for the beaglebone image built on
   2018-08-06. Your image file name will be different.

   When picking a device, use the drive-letter destination, like
   /dev/sdf, not a numbered destination, like /dev/sdf1.  The device
   without a number refers to the entire device, while the device with
   anumber refers to a specific partition.  We want to use the whole
   device.  Downloaded images contain complete information about how
   many partitions there should be, their sizes and types. You don't
   have to format your SD card or create partitions. All the data on
   the SD card will be wiped off during the write process.

3. Use the image by inserting the SD card or USB disk into the target
   device and booting from it.  Also see hardware specific
   instructions on how to prepare your device at
   https://wiki.debian.org/FreedomBox/Hardware

==> freedom-maker_0.31+11.0trisquel1.tar.gz: freedom-maker-0.31+11.0trisquel1/README.md <==
# Freedom-Maker: The FreedomBox image builder

These scripts build FreedomBox-images for various supported hardware
that can then be copied to SD card, USB stick or Hard Disk drive to
boot into FreedomBox.

These scripts are meant for developers of FreedomBox to build images
during releases and for advanced users who intend to build their own
images. Regular users who wish to turn their devices into
FreedomBoxes should instead download the pre-built images.

Get a pre-built image via https://cdimage.trisquel.info/trisquel-images/. There
are images available for all supported target devices.  You also find
the setup instructions on the [Wiki](https://trisquel.info/en/wiki/FreedomBox/).

If you wish to create your own FreedomBox image, perhaps with some
tweaks, see the *Build Images* section below.

# Create Images

## Supported Targets

Trisquel Freedom-maker supports building for the following targets:

| target                | description |
|-----------------------|-------------|
| *a20-olinuxino-lime*	| A20 OLinuXino Lime's SD card |
| *a20-olinuxino-lime2*	| A20 OLinuXino Lime2's SD card |
| *a20-olinuxino-micro*	| A20 OLinuXino MICRO's SD card |
| *amd64*		| Disk image for any machine with amd64 architecture |
| *arm64*		| Disk image for any machine with arm64/aarch64 architecture |
| *armhf*		| Disk image for any machine with arm32 architecture |
| *banana-pro*		| Banana Pro's SD card |
| *beaglebone*		| BeagleBone Black's SD card |
| *cubieboard2*		| Cubieboard2's SD card |
| *cubietruck*		| Cubietruck's SD card |
| *i386*		| Disk image for any machine with i386 architecture |
| *lamobo-r1*		| Lamobo R1 aka BananaPi Router SD card |
| *orange-pi-zero*	| Orange Pi Zero's SD card |
| *pcduino3*		| pcDuino3's SD card |
| *pine64-lts*		| Pine64 LTS board's SD card |
| *pine64-plus*		| Pine64+ board's SD card |
| *qemu-amd64*		| 64-bit image for the Qemu virtualization tool |
| *qemu-i386*		| 32-bit image for the Qemu virtualization tool |

## Running Build

1. Fetch the 'freedom-maker' source code:
    ```
    $ apt source freedom-maker
    ```

2. Install the required dependencies:
    ```shell
    $ sudo apt install btrfs-progs debootstrap kpartx parted qemu-user-static qemu-utils sshpass
    $ sudo apt build-dep freedom-maker
    ```

3. Build images:

    This command has to be started with root (sudo) permission because it needs
    to run "parted".

    ```
    $ cd $(find -type d -name 'freedom-maker-*')
    $ sudo python3 -m freedommaker <TARGET>
    ```
    where: &lt;TARGET&gt; is one of the 'Supported Targets' above.

    Take a break from your computer - this takes some time. :)

    To see the full list of options read the help-page:
    ```
    $ python3 -m freedommaker --help
    ```

The image will show up in *build/*. Copy the image to the
target disk following the instructions in the *Use Images* section.

# Use Images

You'll need to copy the image to a memory card or USB stick. If you don't
use GNU/Linux or prefer a GUI we recommend [etcher](https://etcher.io/)
for this task. Otherwise follow the steps:

1. Figure out which device your card actually is.

    A. Unplug your card.

    B. Run `lsblk -p` to show which storage devices are connected to your system.
    For example, if your computer has one internal SATA storage device
    (the most common configuration), it will be identified as */dev/sda*;
    and the result may look similar to this:

        $ lsblk -p
        NAME        MAJ:MIN RM   SIZE RO TYPE MOUNTPOINTS
        /dev/sda      8:0    0 119.2G  0 disk
        ├─/dev/sda1   8:1    0     2G  0 part /boot
        ├─/dev/sda2   8:2    0  22.5G  0 part /
        └─/dev/sda3   8:3    0  94.8G  0 part /home

    C. Plug in your SDcard and run `lsblk -p` again. Find the new device and note
    the name. For example, if the SDcard is unformatted (empty), the result may
    look similar to this:

        $ lsblk -p
        NAME        MAJ:MIN RM   SIZE RO TYPE MOUNTPOINTS
        /dev/sda      8:0    0 119.2G  0 disk
        ├─/dev/sda1   8:1    0     2G  0 part /boot
        ├─/dev/sda2   8:2    0  22.5G  0 part /
        └─/dev/sda3   8:3    0  94.8G  0 part /home
        /dev/sdb      8:32   1  29.7G  0 disk

    Or, if the SDcard is already formatted, it may look more like this:


        $ lsblk -p
        NAME        MAJ:MIN RM   SIZE RO TYPE MOUNTPOINTS
        /dev/sda      8:0    0 119.2G  0 disk
        ├─/dev/sda1   8:1    0     2G  0 part /boot
        ├─/dev/sda2   8:2    0  22.5G  0 part /
        └─/dev/sda3   8:3    0  94.8G  0 part /home
        /dev/sdb      8:32   1  29.7G  0 disk
        ├─/dev/sdb1   8:33   1   100M  0 part
        └─/dev/sdb2   8:36   1  29.6G  0 part

    D. In the above cases, the newly inserted SDcard is identified
       as */dev/sdb*. To be more certain, you can compare the reported sizes
       (approximately - the SDcard is 30 GB in this example - reported 29.7G).
       Most importantly, */dev/sda*. is usually not the SDcard.
       Carefully note this identifier and use it in the copying step below.

2. Copy the image to your card.  Double check and make sure you don't
   write to your computer's main storage (such as /dev/sda).  Also
   make sure that you don't run this step as root (sudo) to avoid potentially
   overriding data on your hard drive due to a mistake. USB disks and SD
   cards inserted into the system should typically be write accessible
   to normal users. If you don't have permission to write to your SD
   card as a user, you may need to run this command as root. In this
   case triple check everything before you run the command. Another
   safety precaution is to unplug all external disks except the SD
   card before running the command.

   For example, if your SD card is /dev/sdg use the following command:
    ```
    $ xzcat build/freedombox-unstable_2018-08-06_beaglebone-armhf.img.xz | dd bs=4M of=/dev/sdg conv=fsync status=progress
    ```

   The above command is an example for the beaglebone image built on
   2018-08-06. Your image file name will be different.

   When picking a device, use the drive-letter destination, like
   /dev/sdf, not a numbered destination, like /dev/sdf1.  The device
   without a number refers to the entire device, while the device with
   anumber refers to a specific partition.  We want to use the whole
   device.  Downloaded images contain complete information about how
   many partitions there should be, their sizes and types. You don't
   have to format your SD card or create partitions. All the data on
   the SD card will be wiped off during the write process.

3. Use the image by inserting the SD card or USB disk into the target
   device and booting from it.  Also see hardware specific
   instructions on how to prepare your device at
   https://wiki.debian.org/FreedomBox/Hardware
